==> owncloud-4.5.7.tgz: owncloud/core/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "nama applikasi tidak disediakan",
"No category to add?" => "Tiada kategori untuk di tambah?",
"This category already exists: " => "Kategori ini telah wujud",
"Settings" => "Tetapan",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"Cancel" => "Batal",
"No" => "Tidak",
"Yes" => "Ya",
"Ok" => "Ok",
"No categories selected for deletion." => "tiada kategori dipilih untuk penghapusan",
"Error" => "Ralat",
"Password" => "Kata laluan",
"ownCloud password reset" => "Set semula kata lalaun ownCloud",
"Use the following link to reset your password: {link}" => "Guna pautan berikut untuk menetapkan semula kata laluan anda: {link}",
"You will receive a link to reset your password via Email." => "Anda akan menerima pautan untuk menetapkan semula kata laluan anda melalui emel",
"Requested" => "Meminta",
"Login failed!" => "Log masuk gagal!",
"Username" => "Nama pengguna",
"Request reset" => "Permintaan set semula",
"Your password was reset" => "Kata laluan anda telah diset semula",
"To login page" => "Ke halaman log masuk",
"New password" => "Kata laluan baru",
"Reset password" => "Penetapan semula kata laluan",
"Personal" => "Peribadi",
"Users" => "Pengguna",
"Apps" => "Aplikasi",
"Admin" => "Admin",
"Help" => "Bantuan",
"Access forbidden" => "Larangan akses",
"Cloud not found" => "Awan tidak dijumpai",
"Edit categories" => "Edit kategori",
"Add" => "Tambah",
"Create an <strong>admin account</strong>" => "buat <strong>akaun admin</strong>",
"Advanced" => "Maju",
"Data folder" => "Fail data",
"Configure the database" => "Konfigurasi pangkalan data",
"will be used" => "akan digunakan",
"Database user" => "Nama pengguna pangkalan data",
"Database password" => "Kata laluan pangkalan data",
"Database name" => "Nama pangkalan data",
"Database host" => "Hos pangkalan data",
"Finish setup" => "Setup selesai",
"web services under your control" => "Perkhidmatan web di bawah kawalan anda",
"Log out" => "Log keluar",
"Lost your password?" => "Hilang kata laluan?",
"remember" => "ingat",
"Log in" => "Log masuk",
"You are logged out." => "Anda telah log keluar.",
"prev" => "sebelum",
"next" => "seterus"
);

==> owncloud-5.0.9.tgz: owncloud/core/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"No category to add?" => "Tiada kategori untuk di tambah?",
"No categories selected for deletion." => "tiada kategori dipilih untuk penghapusan",
"Sunday" => "Ahad",
"Monday" => "Isnin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Khamis",
"Friday" => "Jumaat",
"Saturday" => "Sabtu",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"Settings" => "Tetapan",
"Cancel" => "Batal",
"No" => "Tidak",
"Yes" => "Ya",
"Ok" => "Ok",
"Error" => "Ralat",
"Share" => "Kongsi",
"Password" => "Kata laluan",
"ownCloud password reset" => "Set semula kata lalaun ownCloud",
"Use the following link to reset your password: {link}" => "Guna pautan berikut untuk menetapkan semula kata laluan anda: {link}",
"You will receive a link to reset your password via Email." => "Anda akan menerima pautan untuk menetapkan semula kata laluan anda melalui emel",
"Username" => "Nama pengguna",
"Request reset" => "Permintaan set semula",
"Your password was reset" => "Kata laluan anda telah diset semula",
"To login page" => "Ke halaman log masuk",
"New password" => "Kata laluan baru",
"Reset password" => "Penetapan semula kata laluan",
"Personal" => "Peribadi",
"Users" => "Pengguna",
"Apps" => "Aplikasi",
"Admin" => "Admin",
"Help" => "Bantuan",
"Access forbidden" => "Larangan akses",
"Cloud not found" => "Awan tidak dijumpai",
"Edit categories" => "Edit kategori",
"Add" => "Tambah",
"Security Warning" => "Amaran keselamatan",
"Create an <strong>admin account</strong>" => "buat <strong>akaun admin</strong>",
"Advanced" => "Maju",
"Data folder" => "Fail data",
"Configure the database" => "Konfigurasi pangkalan data",
"will be used" => "akan digunakan",
"Database user" => "Nama pengguna pangkalan data",
"Database password" => "Kata laluan pangkalan data",
"Database name" => "Nama pangkalan data",
"Database host" => "Hos pangkalan data",
"Finish setup" => "Setup selesai",
"web services under your control" => "Perkhidmatan web di bawah kawalan anda",
"Log out" => "Log keluar",
"Lost your password?" => "Hilang kata laluan?",
"remember" => "ingat",
"Log in" => "Log masuk",
"prev" => "sebelum",
"next" => "seterus"
);
